@@ -1,12 +1,12 @@
 import factory
-from django.contrib.auth.models import User
+from django.conf import settings
 from django.db.models.signals import post_save
 
 
 @factory.django.mute_signals(post_save)
 class UserFactory(factory.django.DjangoModelFactory):
     class Meta:
-        model = User
+        model = settings.AUTH_USER_MODEL
 
     username = factory.Faker('user_name')
     first_name = factory.Faker('first_name')
